function [R0x, R0y] = GetResponsePlacet(handles)
% Get response matrix from Placet, used for steering
global G_quads, global G_dipols, global G_hcors, global G_vcors, global G_hmovers, global G_vmovers;

PlacetDir = '/acc/oper/share/ctf/data/ctfmod/placet/';
PlacetDirExe = [PlacetDir 'placet-development/bin/'];
PlacetDirScripts = [PlacetDir 'decelerator/'];
PlacetDirResults = [PlacetDir 'decelerator/results'];
PlacetDirOnlineExchange = [PlacetDir 'decelerator/online_exchange'];
GuiDir = pwd;

createvmdevices([G_quads, G_dipols, G_hcors, G_vcors, G_hmovers, G_vmovers]);
writevmdevices([G_quads, G_dipols, G_hcors, G_vcors, G_hmovers, G_vmovers], ...;
    readdevices([G_quads, G_dipols, G_hcors, G_vcors, G_hmovers, G_vmovers]));

% Read beam energy/current and write to Placet
cd(PlacetDirOnlineExchange);
E = str2double(get(handles.txtEnStartVal, 'String'));
I = JGetCoValueFesa('CB.SVBPM0150S', 'MeanAtCursor', 'mean');
fid = fopen('virtual.energies', 'w');
fprintf(fid, 'e0 %5.5f', E);
fclose(fid);
fid = fopen('virtual.beamcurrents', 'w');
fprintf(fid, 'I0 %5.5f', I);
fclose(fid);

% Run the model
cd(PlacetDirResults)
disp('Running Placet...');
system(['setenv LD_LIBRARY_PATH ${LD_LIBRARY_PATH}:' PlacetDirExe '; ' ...
    PlacetDirExe '/placet-octave ' PlacetDirScripts 'dec_scripts/main.tcl >&! placet_output.txt']); % Erik:Extra '/'
disp('Placet finished.');

% Convert and load files
system( ['grep -v ^# ' 'R0_tbl12_m0.dat >! R0_tbl12_m0.datm']); % Convert octave output to matlab output
R0_ymovers = load('R0_tbl12_m0.datm');
system( ['grep -v ^# ' 'R0_tbl12_m0_coils.dat >! R0_tbl12_m0_coils.datm']); % Convert octave output to matlab output
R0_ycoils = load('R0_tbl12_m0_coils.datm');
system( ['grep -v ^# ' 'R0_x_tbl12_m0.dat >! R0_x_tbl12_m0.datm']); % convert octave output to matlab output
R0_xmovers = load('R0_x_tbl12_m0.datm');
system( ['grep -v ^# ' 'R0_x_tbl12_m0_coils.dat >! R0_x_tbl12_m0_coils.datm']); % convert octave output to matlab output
R0_xcoils = load('R0_x_tbl12_m0_coils.datm');

cd(GuiDir);

% Scale from PLACET units to ctf3/matlab units
% [mm] / [A] for correctors
% [mm] / [mm] for movers
bpm_ctf = 1e-6; % [m]
bpm_placet = 1e-6; % [m]
% Take out "zero-line BPMs (false and real)
range_BPMs = 5:(size(R0_ycoils,1));  % from CB.BPM0150 to CB.CBPM1030
R0_ycoils = R0_ycoils(range_BPMs, :);
R0_ymovers = R0_ymovers(range_BPMs, :);
R0_xcoils = R0_xcoils(range_BPMs, :);
R0_xmovers = R0_xmovers(range_BPMs, :);

% Take out last corrector (no effect)
R0_ycoils = R0_ycoils(:, 1:end-1);
R0_xcoils = R0_xcoils(:, 1:end-1);

% Correctors
corr_ctf_C = 65.4e-9*1.0; % [rad/ (GeV/c) ]   (one step is 1 A)
corr_placet = 1e-6; % [rad / (GeV/c) ]  (one step is defined as such)
R0_ycoils = R0_ycoils*(corr_ctf_C/corr_placet)*(bpm_ctf/bpm_placet);
R0_xcoils = R0_xcoils*(corr_ctf_C/corr_placet)*(bpm_ctf/bpm_placet);

% movers
R0_xmovers = R0_xmovers*(1 /1)*(bpm_ctf/bpm_placet);

% apply global scale factor
bpm_global_scaling = 1.0;
R0_ycoils = R0_ycoils * bpm_global_scaling;
R0_ymovers = R0_ymovers * bpm_global_scaling;
R0_xcoils = R0_xcoils * bpm_global_scaling;
R0_xmovers = R0_xmovers * bpm_global_scaling;
  
R0x = [R0_xcoils R0_xmovers];
R0y = [R0_ycoils R0_ymovers];


% R0x = 1;
% R0y = 1;