function handles = MakeGUIPanelPETS(hObject, handles)
% Make all ui controls for the 2nd user screen (offset, BPM pulses, power pred. etc.)
global G_PetsApertureRadius;

% General parameters
leftmargin = 13;

%% Panel for the predicted power/energy
area = [250 625 945 109];
topmargin = 30;
linespacing = 26;
labelSize = [200 14];
editboxSize = [55 20];
mathaxesSize = [70 labelSize(2)+linespacing];
a = double(imread('latex_powerPredEquation.jpg'));
formulaaxesSize = [size(a,2) size(a,1)];
% formulaaxesSize = [420 labelSize(2)+linespacing];

ypos = area(4)-topmargin-labelSize(2) - [0, (editboxSize(2)-labelSize(2))/2];
xpos = leftmargin + [0, mathaxesSize(1)+[0, editboxSize(1)+30+[0, formulaaxesSize(1)+30+[0, labelSize(1)+[0, editboxSize(1)]]]]];
handles.pnlPETSPred = uipanel('Units', 'pixels', 'Visible', 'off', ...
    'Title', 'Predicted values', 'Position', area, 'FontSize', 9);
handles.axPowerPredParams = axes('Parent', handles.pnlPETSPred, 'Units', ...
    'pixels', 'Position', [xpos(1), ypos(1)-linespacing, mathaxesSize]);
handles.edtPowerPredFormFactor = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'edit', 'FontSize', 9, 'Position', ...
    [xpos(2), ypos(2), editboxSize], 'String', '0.97', 'BackgroundColor', 'w');
handles.axPowerPredFormula = axes('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Position', [xpos(3), ypos(1)-linespacing, formulaaxesSize]);
handles.txtPowerPred = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'text', 'FontSize', 9, 'Position', ...
    [xpos(4), ypos(1), labelSize], 'HorizontalAlignment', 'left', ...
    'String', 'PETS predicted output power [MW]:');
handles.txtPowerPredVal = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'text', 'Position', [xpos(5), ypos(2), editboxSize], ...
    'FontSize', 11, 'HorizontalAlignment', 'right', 'String', '138.76');
ypos = ypos - linespacing*ones(1,2);
handles.edtPowerPredDeltaF = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'edit', 'FontSize', 9, 'Position', ...
    [xpos(2), ypos(2), editboxSize], 'String', '0', 'BackgroundColor', 'w');
handles.txtEnergyLossPred = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'text', 'FontSize', 9, 'Position', ...
    [xpos(4), ypos(1), labelSize], 'HorizontalAlignment', 'left', ...
    'String', 'Predicted energy loss per PETS [MV]:');
handles.txtEnergyLossPredVal = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'text', 'Position', ...
    [xpos(5), ypos(2), editboxSize], 'FontSize', 11, ...
    'HorizontalAlignment', 'right', 'String', '5.1934');
ypos = ypos(1) - linespacing;
handles.btnPowerPred = uicontrol('Parent', handles.pnlPETSPred, ...
    'Units', 'pixels', 'Style', 'pushbutton', 'FontSize', 9, 'Position', ...
    [xpos(4), ypos, labelSize(1)+editboxSize(1), 22], ...
    'String', 'Update prediction from parameters in file', ...
    'Callback', {'btnPowerPred_callback', handles});

%% Panel for controlling beam misalignment in one PETS
area = [575 375.6 618 244];
labelSize = [125 14];
editboxSize = [55 20];
buttonSize = [180 22];
posGraphSize = [145 145];
realposGraphSize = [labelSize(1)+editboxSize(1)-20, 100];
linespacing = 25.5;

ypos = area(4) - topmargin - labelSize(2);
handles.pnlPETSPos = uipanel('Units', 'pixels', 'Visible', 'off', ...
    'Title', 'Beam position within the first PETS', 'Position', area, 'FontSize', 9);
handles.txtPETSPosX = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'text', 'Position', ...
    [leftmargin, ypos, labelSize], 'HorizontalAlignment', 'left', ...
    'String', 'Wanted offset X [mm]:', 'FontSize', 9);
handles.edtPETSPosX = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'BackgroundColor', 'white', 'Position', ...
    [leftmargin+labelSize(1), ypos-3, editboxSize], 'String', '0', 'FontSize', 9);
ypos = ypos - linespacing;
handles.txtPETSPosY = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'text', 'FontSize', 9, 'Position', ...
    [leftmargin, ypos, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Wanted offset Y [mm]:');
handles.edtPETSPosY = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'BackgroundColor', 'white', 'Position', ...
    [leftmargin+labelSize(1), ypos-3, editboxSize], 'String', '0', 'FontSize', 9);
ypos = ypos - linespacing;
handles.txtPETSPosR = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'text', 'FontSize', 9, 'Position', ...
    [leftmargin, ypos, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Radial offset [mm]:');
handles.txtPETSPosRVal = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'text', 'FontSize', 11, 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize], 'String', '0');
ypos = ypos - linespacing - 10;
handles.btnPETSPos = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Style', 'pushbutton', 'Position', ...
    [leftmargin, ypos, buttonSize], 'String', 'Write desired offset to HW');
ypos = ypos - linespacing;
handles.txtPETSAperture = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Style', 'text', 'Position', ...
    [leftmargin, ypos, labelSize(1)+editboxSize(1), labelSize(2)], ...
    'HorizontalAlignment', 'left', 'String', ...
    ['PETS Aperture radius: ' num2str(G_PetsApertureRadius) ' mm']);

xpos = leftmargin+labelSize(1) + editboxSize(1) + 40;
ypos = area(4) - topmargin - posGraphSize(2);
handles.axPETSPos = axes('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Position', ...
    [xpos, ypos, posGraphSize]);

% Initiate figure for the PETS aperture
edtPETSPos_callback(0, 0, handles);

% Button for writing to HW
% ypos = area(4) - topmargin - buttonSize(2) + 4;


% Display the real position
% ypos = ypos - linespacing;
% handles.txtPETSPosReal = uicontrol('Parent', handles.pnlPETSPos, ...
%     'Units', 'pixels', 'Style', 'text', 'Position', ...
%     [xpos, ypos, labelSize(1)+editboxSize(1), labelSize(2)], ...
%     'HorizontalAlignment', 'left', 'String', 'Measured positions [mm]:');
xpos = leftmargin+labelSize(1) + editboxSize(1) + 240;
ypos = area(4) - topmargin - realposGraphSize(2) - 10;
handles.axPETSPosReal = axes('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Position', ...
    [xpos, ypos, realposGraphSize], 'XTick', [], 'box', 'on');
title('Measured positions [mm];', 'Parent', handles.axPETSPosReal, ...
    'FontSize', 9);
ypos = ypos - linespacing - 5;  % Texts with measured X positions
BPMTextSpacing = realposGraphSize(1)/3;
handles.txtPETSPosBPMx = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Style', 'text', 'String', 'X:', 'Position', ...
    [xpos-20, ypos+3, 20, labelSize(2)], 'HorizontalAlignment', 'left');
handles.txtPETSPosBPM1x = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);
handles.txtPETSPosBPM2x = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos+BPMTextSpacing+1, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);
handles.txtPETSPosBPM3x = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos+2+2*BPMTextSpacing, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);
ypos = ypos - linespacing;  % Texts with measured Y positions
handles.txtPETSPosBPMy = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'FontSize', 9, 'Style', 'text', 'String', 'Y:', 'Position', ...
    [xpos-20, ypos+3, 20, labelSize(2)], 'HorizontalAlignment', 'left');
handles.txtPETSPosBPM1y = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);
handles.txtPETSPosBPM2y = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos+BPMTextSpacing+1, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);
handles.txtPETSPosBPM3y = uicontrol('Parent', handles.pnlPETSPos, ...
    'Units', 'pixels', 'Style', 'edit', 'Enable', 'off', 'Position', ...
    [xpos+2+2*BPMTextSpacing, ypos, BPMTextSpacing-2, editboxSize(2)], ...
    'HorizontalAlignment', 'center', 'FontSize', 8);

% Make callbacks after the controls since they need to 'know' the values
set(handles.edtPETSPosX, 'Callback', {'edtPETSPos_callback', handles});
set(handles.edtPETSPosY, 'Callback', {'edtPETSPos_callback', handles});
set(handles.btnPETSPos, 'Callback', {'btnPETSPos_callback', handles});

%% Panel for BPM signals
area = [11 12 550 607.6];
topmargin = 24;
labelSize = [245 14];
labelSizeSmall = [125 14];
editboxSize = [55 18];
linespacing = 25;
graphSize1 = [470 120];
graphSize2 = [470 90];
YMaxHor = 10;    % Scaling y axes for position plots
YMaxVer = 10;
handles.pnlPulse = uipanel('Units', 'pixels', 'Visible', 'off', ...
    'Title', 'BPM and RF signals', 'Position', area, 'FontSize', 9);
ypos = area(4) - topmargin - graphSize1(2);
handles.axPowCurPulses = axes('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Position', [45, ypos graphSize1], 'YLim', [-50 50], 'XLim', [0 511/0.5], ...
    'FontSize', 9, 'box', 'on');

ypos = ypos - linespacing - 28;    % Under graph
handles.txtPowerMeasL = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin, ypos, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Measured PETS output power, left arm [MW]:');
handles.txtPowerMeasLVal = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize]);
xpos = leftmargin+graphSize1(1)-editboxSize(1)-labelSizeSmall(1)+25;
handles.txtPowerMeasReflL = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', ...
    [xpos, ypos, labelSizeSmall], ...
    'HorizontalAlignment', 'left', 'String', 'Refl. power, left [MW]:');
handles.txtPowerMeasReflLVal = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [xpos+labelSizeSmall(1), ypos, editboxSize-[5 0]]);
% xpos = leftmargin+labelSize(1)+editboxSize(1)+60;

ypos = ypos - linespacing;
handles.txtPowerMeasR = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin, ypos, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Measured PETS output power, right arm [MW]:');
handles.txtPowerMeasRVal = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize]);
handles.txtPowerMeasReflR = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', ...
    [xpos, ypos, labelSizeSmall], ...
    'HorizontalAlignment', 'left', 'String', 'Refl. power, right [MW]:');
handles.txtPowerMeasReflRVal = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [xpos+labelSizeSmall(1), ypos, editboxSize-[5 0]]);

ypos = ypos - linespacing;
handles.txtPowerMeasTot = uicontrol('Parent', handles.pnlPulse', 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin, ypos, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Measured PETS output power, total [MW]:');
handles.txtPowerMeasTotVal = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize]);

ypos = ypos - 1.6*linespacing;
handles.txtCurMeas210 = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin ypos labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Mean current at CB.STBPS0210S [A]:');
handles.txtCurMeas210Val = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize]);

ypos = ypos - linespacing;
handles.txtCurMeas250 = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin ypos labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Mean current at CB.STBPS0250S [A]:');
handles.txtCurMeas250Val = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 11, 'HorizontalAlignment', 'right', 'Position', ...
    [leftmargin+labelSize(1), ypos-2, editboxSize]);

ypos = ypos - linespacing - graphSize2(2);
handles.axHorPulses = axes('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Position', [45 ypos graphSize2], 'FontSize', 9, 'YLim', [-YMaxHor YMaxHor], ...
    'box', 'on');

ypos = ypos - linespacing*0.8 - graphSize2(2);
handles.axVerPulses = axes('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Position', [45 ypos graphSize2], 'FontSize', 9, 'YLim', [-YMaxVer YMaxVer], ...
    'box', 'on');

ypos = ypos - linespacing - 30;
handles.txtSavePulses = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'FontSize', 9, 'Position', [leftmargin, ypos+4, labelSize], ...
    'HorizontalAlignment', 'left', 'String', 'Save number of pulses:');
xpos = leftmargin + labelSize(1) - editboxSize(1) - 30;
handles.edtSavePulses = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'edit', 'String', '1', 'BackgroundColor', 'white', 'Position', ...
    [xpos, ypos+2, editboxSize], 'FontSize', 8);
xpos = xpos + editboxSize(1) + 10;
handles.btnSavePulses = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'togglebutton', 'FontSize', 9, 'String', 'Save', 'Position', ...
    [xpos, ypos-1, 65, 22]);
xpos = xpos + 75;
handles.txtSavePulsesWait = uicontrol('Parent', handles.pnlPulse, 'Units', 'pixels', ...
    'Style', 'text', 'Position', [xpos, ypos+4, 140 labelSize(2)], ...
    'HorizontalAlignment', 'left', 'String', 'Saving pulses...', ...
    'ForegroundColor', 'red', 'Visible', 'off', 'FontSize', 9);

% Callbacks
set(handles.btnSavePulses, 'Callback', {'btnSavePulses_callback', handles});

%% Panel for power production and phase
area = [575 12 618 358.2];
topmargin = 24;
labelSize = [245 14];
labelSizeSmall = [33 14];
editboxSize = [55 20];
linespacing = 25;
graphSize = [538 90];

handles.pnlPowerProd = uipanel('Units', 'pixels', 'Visible', 'off', ...
    'Title', 'Power production', 'Position', area, 'FontSize', 9);
ypos = area(4) - topmargin - linespacing;
handles.axPowerProdFF = axes('Parent', handles.pnlPowerProd, 'Units', 'pixels', ...
    'Position', [leftmargin ypos+3 labelSizeSmall]);
handles.edtPowerProdFF = uicontrol('Parent', handles.pnlPowerProd, 'Units', 'pixels', ...
    'Style', 'edit', 'Position', [50 ypos editboxSize], ...
    'String', 0.97, 'BackgroundColor', 'white', 'FontSize', 8);

ypos = ypos - linespacing - graphSize(2) - 13.6;
handles.axPowerProd = axes('Parent', handles.pnlPowerProd, 'Units', 'pixels', ...
    'Position', [50 ypos graphSize], 'FontSize', 9, 'box', 'on');

ypos = ypos - linespacing*0.8 - graphSize(2);
handles.axPowerPhase = axes('Parent', handles.pnlPowerProd, 'Units', 'pixels', ...
    'Position', [50 ypos graphSize], 'FontSize', 9, 'box', 'on');

%% Update GUI data
guidata(hObject, handles);