function MakeSteeringControls(handles)
% Positions the textboxes for steering at the correct positions under the 
% corresponding BPMs.

global G_pos_bpm;
global G_l_tbl;

% Only use the 3rd BPM and onwards for steering
pos_bpm_steering = G_pos_bpm(1,3:length(G_pos_bpm));

%% Set the positions and sizes
% Find the closest position in pixels between BPMs
area = get(handles.axLattice, 'Position');
xpos = area(1)*ones(size(pos_bpm_steering)) + pos_bpm_steering/G_l_tbl*area(3);
mindist = xpos(2)-xpos(1);
for i = 2:size(xpos,2)
    if (xpos(i) - xpos(i-1) < mindist)
        mindist = xpos(i) - xpos(i-1);
    end
end

ctrlSize = [0.95*mindist 20];
xpos = xpos - ctrlSize(1)/2 * ones(size(xpos));
ypos = [55 10];

% Make global matrices of the corrector current and magnet mover textbox handles
global ICor_handles;
global posQuads_handles;
ICor_handles = [handles.edtIC1X handles.edtIC2X handles.edtIC3X handles.edtIC4X;
                handles.edtIC1Y handles.edtIC2Y handles.edtIC3Y handles.edtIC4Y];
posQuads_handles = [handles.edtX1  handles.edtX2  handles.edtX3  handles.edtX4 ...
                    handles.edtX5  handles.edtX6  handles.edtX7  handles.edtX8 ...
                    handles.edtX9  handles.edtX10 handles.edtX11 handles.edtX12 ...
                    handles.edtX13 handles.edtX14 handles.edtX15 handles.edtX16;
                    handles.edtY1  handles.edtY2  handles.edtY3  handles.edtY4 ...
                    handles.edtY5  handles.edtY6  handles.edtY7  handles.edtY8 ...
                    handles.edtY9  handles.edtY10 handles.edtY11 handles.edtY12 ...
                    handles.edtY13 handles.edtY14 handles.edtY15 handles.edtY16];

% Set positions and sizes of magnet mover textboxes
for i = 1:size(posQuads_handles,1)
    for j = 1:size(posQuads_handles,2)
        set(posQuads_handles(i,j), 'Position', [xpos(j) ypos(i) ctrlSize], ...
            'FontSize', 8, 'Visible', 'on');
    end
end

% Set some corrector magnet positions
smallCtrlSize = [ctrlSize(1)*0.8, ctrlSize(2)]; % Smaller textboxes for currents
xcor = ctrlSize(1)-smallCtrlSize(1);            % Correct for size difference in position
for i = 1:size(ICor_handles,1)
    for j = 1:size(ICor_handles,2)
        set(ICor_handles(i,j), 'Visible', 'on', 'FontSize', 8, ...
            'Position', [xpos(j)-180+(4-j)*xcor, ypos(i), smallCtrlSize]);
    end
end

% Set bending magnet current position
xposB = area(1) + area(3) - 140;
set(handles.edtBendCurrent, 'Position', [xposB ypos(1) 100 ctrlSize(2)], ...
    'FontSize', 8, 'Visible', 'on');

% Set labels at the correct places
set(handles.txtPosX, 'Position', [xpos(1) ypos(1)+20 180 18], 'Visible', 'on');
set(handles.txtPosY, 'Position', [xpos(1) ypos(2)+20 180 18], 'Visible', 'on');
set(handles.txtICX, 'Position', [xpos(1)-180+3*xcor ypos(1)+20 150 18], 'Visible', 'on');
set(handles.txtICY, 'Position', [xpos(1)-180+3*xcor ypos(2)+20 150 18], 'Visible', 'on');
set(handles.txtBendCurrent, 'Position', [xposB ypos(1)+20 100 18], 'Visible', 'on');

% Set buttons at the correct places
set(handles.btnResetSteering, 'Position', [13 ypos(1) 145 20], 'Visible', 'on');
set(handles.btn1to1Steering, 'Position', [13 ypos(2)+22 145 20], 'Visible', 'on');
set(handles.btnDFSteering, 'Position', [13 ypos(2) 145 20], 'Visible', 'on');
set(handles.btnEditSteering, 'Position', [xposB ypos(2)+22 100 20], 'Visible', 'on');
set(handles.btnSteerToHW, 'Position', [xposB, ypos(2) 100 20], 'Visible', 'on');

%% Example text
% TODO: Replace random numbers by actual positions
for i = 1:size(posQuads_handles,1)
    for j = 1:size(posQuads_handles,2)
        set(posQuads_handles(i,j), 'String', floor(20000*rand(1,1)-10000));
    end
end

for i = 1:size(ICor_handles,1)
    for j = 1:size(ICor_handles,2)
        set(ICor_handles(i,j), 'String', '0');
    end
end