function [x,y] = PhaseSpaceEllipse(alpha, beta, epsilon)
% Get coordinates of a parametrized Phase Space ellipse.
% -------------------------------------
% gamma u^2 + 2 alpha u u' + beta u'^2 = epsilon
% gamma is calculated automatically. Returns parametrized x- and y-vectors
% for plotting.
gamma = (1+alpha^2)/beta;

a = gamma; b = 2*alpha; c = beta; d = 0; e = 0; f = -epsilon;

delta = det([2*a, b, d; b, 2*c, e; d, e, 2*f]);
phi = b^2 - 4*a*c;
rho = 0.5 * delta/phi;
h = (2*c*d - b*e)/phi;
k = (2*a*e - b*d)/phi;
lambda = abs(a-c)/sqrt(b^2 + (a-c)^2);
S = sqrt((1-lambda)/2);
C = sqrt((1+lambda)/2);
P = a*C^2 + c*S^2 + b*C*S;
Q = a*S^2 + c*C^2 - b*C*S;
alpha = sqrt(rho/P);
beta = sqrt(rho/Q);

t = 0:pi/100:2*pi;
x = alpha*C*cos(t) - beta*S*sin(t) + h;
y = alpha*S*cos(t) + beta*C*sin(t) + k;