function ReadBpmsAndDisplay(handles)
% Global variables (defined elsewhere, written here because of scope)
global G_pos_bpm;
global G_l_tbl;
global G_isonline;
global G_last_tstamp;
global G_path;

isreaderror = 0;

if G_isonline
    try
        fid = fopen([G_path '/BPMOutput/mean.txt']);
        tstamp = str2double(fgetl(fid));
        input = textscan(fid, '%s %f');
        input = input{:,2}';
        fclose(fid);
    catch
        s = lasterror;
        disp(['Error when reading mean BPM values: ' s.message]);
    end
    
    % Check if timestamp is the same as the last one
    if tstamp == G_last_tstamp
        set(handles.txtBpmStatus, 'String', char('BPM status:', 'Not updating'), ...
            'ForegroundColor', 'r');
        isreaderror = 1;
    elseif (size(input,2)) == 57
        % Update the timestamp with the new value
        G_last_tstamp = tstamp;
        
        testvectorX = [input(55) input(1) input(7:3:52) input(4)];
        testvectorI = [input(56) input(2) input(8:3:53) input(5)];
        testvectorY = [input(57) input(3) input(9:3:54) input(6)];
        
        % Set to zero if values are NaN, to be able to get a plot
        testvectorX(isnan(testvectorX)) = 0;
        testvectorI(isnan(testvectorI)) = 0;
        testvectorY(isnan(testvectorY)) = 0;
        
        set(handles.txtBpmStatus, 'String', char('BPM status:', 'Reading ok'), ...
            'ForegroundColor', 'b');
    else
        set(handles.txtBpmStatus, 'String', char('BPM status:', 'Read error!'), ...
            'ForegroundColor', 'r');
        isreaderror = 1;
    end
end
if ~G_isonline || isreaderror
    testvectorX = 0.02*(2*randn(1, size(G_pos_bpm,2)) - ones(1, size(G_pos_bpm,2)));
    testvectorY = 0.02*(2*randn(1, size(G_pos_bpm,2)) - ones(1, size(G_pos_bpm,2)));
    testvectorI = 2.0*rand(1, size(G_pos_bpm,2)) + 27.0*ones(1, size(G_pos_bpm,2));
end

%% Get the correct scale from the slider
scale = round(get(handles.sldBPMScale, 'Value'));
YPosLim = [-3 3];
YPosTick = -3:3;
switch scale
%     case 1
%         YPosLim = [-0.03 0.03]; YPosTick = -0.03:0.01:0.03;
%     case 2
%         YPosLim = [-0.06 0.06]; YPosTick = -0.06:0.02:0.06;
%     case 1
%         YPosLim = [-0.09 0.09]; YPosTick = -0.09:0.03:0.09;
    case 1
        YPosLim = [-0.12 0.12]; YPosTick = -0.12:0.04:0.12;
    case 2
        YPosLim = [-0.15 0.15]; YPosTick = -0.15:0.05:0.15;
    case 3
        YPosLim = [-0.3 0.3]; YPosTick = -0.3:0.1:0.3;
    case 4
        YPosLim = [-0.45 0.45]; YPosTick = -0.45:0.15:0.45;
    case 5
        YPosLim = [-0.6 0.6]; YPosTick = -0.6:0.2:0.6;
    case 6
        YPosLim = [-0.9 0.9]; YPosTick = -0.9:0.3:0.9;
    case 7
        YPosLim = [-1.2 1.2]; YPosTick = -1.2:0.4:1.2;
    case 8
        YPosLim = [-1.5 1.5]; YPosTick = -1.5:0.5:1.5;
    case 9
        YPosLim = [-3 3]; YPosTick = -3:1:3;
    case 10
        YPosLim = [-6 6]; YPosTick = -6:2:6;
    case 11
        YPosLim = [-9 9]; YPosTick = -9:3:9;
    case 12
        YPosLim = [-12 12]; YPosTick = -12:4:12;
    case 13
        YPosLim = [-15 15]; YPosTick = -15:5:15;
end

%% Choose scale for the current
maxCurrentAmplitude = 18;
YCurTick = -[6 5 4 3 2 1 0] / 6 * maxCurrentAmplitude;

%% Plotting.
if ~isreaderror
    try
    cla(handles.axPos);
    [ax,H1,H2] = plotyy(handles.axPos, G_pos_bpm(1,:), testvectorI, G_pos_bpm(1,:), testvectorX, ...
        'bar', 'plot');
    set(H1, 'BarWidth', 0.5, 'FaceColor', [0.2 0.9 0.2]);
    set(H2, 'Color', 'b', 'Marker', 's', 'MarkerSize', 3, 'MarkerEdgeColor', ...
        'k', 'MarkerFaceColor', [0.8 1 0], 'LineWidth', 2);
    hold(ax(2),'on')
    plot(handles.axPos, G_pos_bpm(1,:), testvectorY, 'r-o', 'LineWidth', 2, 'MarkerSize', 4, ...
        'MarkerEdgeColor', 'k', 'MarkerFaceColor', [0 1 0.8], 'Parent', ax(2));
    hold(ax(2),'off')
    
    set(ax, 'XLim', [0 G_l_tbl], 'XTick', [], 'Box', 'on', 'YGrid', 'on');
	set(ax(1), 'YLim', [-maxCurrentAmplitude 0], 'YTick', YCurTick);
%     set(ax(1), 'YLim', [0 3]-1, 'YTick', [0 0.5 1.0 1.5 2.0 2.5 3.0]-1);
    set(ax(2), 'YLim', YPosLim, 'YTick', YPosTick);
    
    yrange = get(ax(1), 'YLim'); % To make text at the correct place
    text(0.05*G_l_tbl, yrange(2)-0.00*(yrange(2)-yrange(1)), ...
       '\fontsize{16}\it{I} \fontsize{12}\rm[A]', 'Parent', handles.axPos, ...
       'VerticalAlignment', 'top', 'HorizontalAlignment', 'left');
    text(0.98*G_l_tbl, yrange(2)-0.00*(yrange(2)-yrange(1)), ...
       {'\fontsize{16}\it\color{blue}x\color{black}, \color{red}y'; ...
       '\fontsize{12}\rm\color{black}[mm]'}, ...
        'VerticalAlignment', 'top', 'HorizontalAlignment', 'right', ...
        'Parent', handles.axPos);
    catch
        s = lasterror;
        disp(['Error when plotting orbit: ' s.message]);
    end
end