function Steering1to1(R0x, R0y, isGui, handles)
% Uses response matrices from an earlier Placet simulations to do 1-to-1 
% steering in TBL. Conversion factors already applied in R matrices.
% Can work outside GUI by setting 'isGui' to 0.
global G_path;              % Program path
global ICor_handles;        % Matrix of GUI handles
global posQuads_handles;    % Matrix of GUI handles

%% Read BPM mean values
try
    fid = fopen([G_path '/BPMOutput/mean.txt']);
    str2double(fgetl(fid)); % Timestamp
    input = textscan(fid, '%s %f');
    input = input{:,2}';
    fclose(fid);
catch
    s = lasterror;
    disp(['Error when reading mean BPM values: ' s.message]);
end

try
    x = [input(1) input(7:3:52) input(4)]'; % Without Bpm0930 here
    y = [input(3) input(9:3:54) input(6)]'; % Without Bpm0930 here
catch
    s = lasterror;
    disp(['Error when indexing BPM readings: ' s.message]);
    disp(['Size of BPM reading vector: ' num2str(length(input))]);
    return;
end

% TEMP: Change some vals for testing.
% x(5:6) = [2 3];
% y(10:11) = [3 1];

% Set NaN values to zero
x(isnan(x)) = 0;
y(isnan(y)) = 0;

%% Calculate angles
deltaThetaX = -pinv(R0x) * x;
deltaThetaY = -pinv(R0y) * y;

% % Get beam momentum
% E = str2double(get(handles.txtEnStartVal, 'String'));
% p = sqrt(E^2 - 0.510998902^2);	% [MeV/c]

% % Determine the corresponding changes in corrector currents
% deltaICorX = deltaThetaX([1 2 end]) * p / 65.4;   % [A]
% deltaICorY = deltaThetaY([1 2 end]) * p / 65.4;   % [A]

%% Read from control system
% Get the current corrector currents
hcors = zeros(1, 3);
vcors = zeros(1, 3);
hcors(1) = JGetCoValueFesa('CB.DHD0130', 'Acquisition', 'current');
hcors(2) = JGetCoValueFesa('CB.DHD0140', 'Acquisition', 'current');
hcors(3) = JGetCoValueFesa('CB.DHD1040', 'Acquisition', 'current');
vcors(1) = JGetCoValueFesa('CB.DVD0130', 'Acquisition', 'current');
vcors(2) = JGetCoValueFesa('CB.DVD0140', 'Acquisition', 'current');
vcors(3) = JGetCoValueFesa('CB.DVD1040', 'Acquisition', 'current');

% Get the current quad positions
hmovs = zeros(1,16);
vmovs = zeros(1,16);
hmovs(1) = JGetCoValueFesa('CB.MOV0205-H', 'Position', 'position');
hmovs(2) = JGetCoValueFesa('CB.MOV0245-H', 'Position', 'position');
hmovs(3) = JGetCoValueFesa('CB.MOV0305-H', 'Position', 'position');
hmovs(4) = JGetCoValueFesa('CB.MOV0345-H', 'Position', 'position');
hmovs(5) = JGetCoValueFesa('CB.MOV0405-H', 'Position', 'position');
hmovs(6) = JGetCoValueFesa('CB.MOV0445-H', 'Position', 'position');
hmovs(7) = JGetCoValueFesa('CB.MOV0505-H', 'Position', 'position');
hmovs(8) = JGetCoValueFesa('CB.MOV0545-H', 'Position', 'position');
hmovs(9) = JGetCoValueFesa('CB.MOV0605-H', 'Position', 'position');
hmovs(10) = JGetCoValueFesa('CB.MOV0645-H', 'Position', 'position');
hmovs(11) = JGetCoValueFesa('CB.MOV0705-H', 'Position', 'position');
hmovs(12) = JGetCoValueFesa('CB.MOV0745-H', 'Position', 'position');
hmovs(13) = JGetCoValueFesa('CB.MOV0805-H', 'Position', 'position');
hmovs(14) = JGetCoValueFesa('CB.MOV0845-H', 'Position', 'position');
hmovs(15) = JGetCoValueFesa('CB.MOV0905-H', 'Position', 'position');
hmovs(16) = JGetCoValueFesa('CB.MOV0945-H', 'Position', 'position');
vmovs(1) = JGetCoValueFesa('CB.MOV0205-V', 'Position', 'position');
vmovs(2) = JGetCoValueFesa('CB.MOV0245-V', 'Position', 'position');
vmovs(3) = JGetCoValueFesa('CB.MOV0305-V', 'Position', 'position');
vmovs(4) = JGetCoValueFesa('CB.MOV0345-V', 'Position', 'position');
vmovs(5) = JGetCoValueFesa('CB.MOV0405-V', 'Position', 'position');
vmovs(6) = JGetCoValueFesa('CB.MOV0445-V', 'Position', 'position');
vmovs(7) = JGetCoValueFesa('CB.MOV0505-V', 'Position', 'position');
vmovs(8) = JGetCoValueFesa('CB.MOV0545-V', 'Position', 'position');
vmovs(9) = JGetCoValueFesa('CB.MOV0605-V', 'Position', 'position');
vmovs(10) = JGetCoValueFesa('CB.MOV0645-V', 'Position', 'position');
vmovs(11) = JGetCoValueFesa('CB.MOV0705-V', 'Position', 'position');
vmovs(12) = JGetCoValueFesa('CB.MOV0745-V', 'Position', 'position');
vmovs(13) = JGetCoValueFesa('CB.MOV0805-V', 'Position', 'position');
vmovs(14) = JGetCoValueFesa('CB.MOV0845-V', 'Position', 'position');
vmovs(15) = JGetCoValueFesa('CB.MOV0905-V', 'Position', 'position');
vmovs(16) = JGetCoValueFesa('CB.MOV0945-V', 'Position', 'position');

%% Calculate new values
% Calculate the new corrector currents
corcurs = zeros(2, 3);
corcurs(1,:) = hcors + deltaThetaX([1 2 end])';
corcurs(2,:) = vcors + deltaThetaY([1 2 end])';

% Calculate the new quad positions
movpos = zeros(2, 16);
movpos(1,:) = hmovs + deltaThetaX(3:end-1)';
movpos(2,:) = vmovs + deltaThetaY(3:end-1)';

%% Set values to GUI text boxes
if isGui
    set(handles.btnEditSteering, 'Value', 1);
    ControlSteeringControls(1, handles);
    
    % Write corrector currents to text boxes
    for i = 1:size(ICor_handles,1)
        for j = 1:size(ICor_handles,2)-1
            set(ICor_handles(i,j+1), 'String', num2str(corcurs(i,j), '%3.2f'));
        end
    end
    
    % Quad positions
    for i = 1:size(posQuads_handles,1)
        for j = 1:size(posQuads_handles,2)
            set(posQuads_handles(i,j), 'String', num2str(movpos(i,j), '%4.0f'));
        end
    end
end