function [betaX, alphaX, betaY, alphaY] = ...
    TransportTwiss_BeforeWall(I1, I2, beta0x, alpha0x, beta0y, alpha0y, E)
% Transports twiss parameters from the quad scan to the start of the
% lattice

% Constants
CLIGHT	= 299792458;
E8      = E;

LQL     = 0.220;                % length of QL
l       = LQL;
ECQD	= 0.056;                % excitation constant dB/dx/I = 0.056 T/Am
P08     = sqrt(E8^2 - 0.510998902^2);	% mmomentum
FQD     = CLIGHT * 1E-6 * ECQD; % for new QL3 type, QXD, water cooled

% IQTL2a = 16;
% IQTL2b = 16;
isquadzero = 0;
IQTL2a = I1
IQTL2b = I2
if IQTL2a == 0
    IQTL2a = 1e-8;
    isquadzero = 1;
end
if IQTL2b == 0
    IQTL2b = 1e-8;
    isquadzero = 1;
end
if isquadzero == 1
    disp('Warning: One or more quadrupole currents were 0 A. Setting to 1e-8 for calculation.');
end

kQDDa    =  -FQD * IQTL2a / P08;
kQFDa    =  FQD * IQTL2b / P08;

%kQDDa =  abs(kQDDa)
%kQFDa =  abs(kQFDa)

OO = zeros(2,2);

% Thick lens - focusing quad
k = abs(kQDDa);
phi = l*sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4_D = [M_D OO; OO M_F];

% Thick lens - defocusing quad
k = abs(kQFDa);
phi = l*sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4_F = [M_F OO; OO M_D];

% Drift spaces
d1 = 0.25;
M_0 = [1 d1; 0 1];
M4_01 = [M_0 OO; OO M_0];

d2 = 3.431471;
M_0 = [1 d2; 0 1];
M4_02 = [M_0 OO; OO M_0];

% Total matrix
M4 = M4_02 * M4_F * M4_01 * M4_D;

B0x = [beta0x   -alpha0x;   -alpha0x   (1+alpha0x^2)/beta0x];
B0y = [beta0y   -alpha0y;   -alpha0y   (1+alpha0y^2)/beta0y];

B0 = [B0x  OO;  OO  B0y];

B = inv(M4) * B0 * inv(M4');
% B = M4 * B0 * M4'; % forward solution, for testing

betaX = B(1,1);
alphaX = -B(1,2);
betaY = B(3,3);
alphaY = -B(3,4);

