function UpdatePhaseSpace(handles)
% Makes the two ellipses of the phase space plot

%% Read the twiss parameters and find the geometrical emittance
beta0X = str2double(get(handles.edtBetaX,'String'));
alpha0X = str2double(get(handles.edtAlphaX,'String'));
beta0Y = str2double(get(handles.edtBetaY,'String'));
alpha0Y = str2double(get(handles.edtAlphaY,'String'));
epsilonNX = str2double(get(handles.edtEpsilonX, 'String'));
epsilonNY = str2double(get(handles.edtEpsilonY, 'String'));

% Transport the Twiss parameters backwards before the wall
% I1 = str2double(get(handles.edtCurrent1, 'String'));
% I2 = str2double(get(handles.edtCurrent2, 'String'));
E = str2double(get(handles.txtEnStartVal, 'String'));
% [betaX, alphaX, betaY, alphaY] = ...
%     TransportTwiss_BeforeWall(I1, I2, beta0X, alpha0X, beta0Y, alpha0Y, E);

E_rest = 0.510998910;
gamma = E / E_rest;
beta = sqrt( 1 - 1/gamma^2 );
epsilonX = epsilonNX / beta / gamma;
epsilonY = epsilonNY / beta / gamma;


%% Plot the two ellipses
axes(handles.axPhaseSpace)
cla;
hold on;

% Plot the x, x' ellipse
[x xp] = PhaseSpaceEllipse(alpha0X, beta0X, epsilonX);
plot(x, xp, 'Color', 'b', 'LineWidth', 2);

% Plot the y, y' ellipse
[y yp] = PhaseSpaceEllipse(alpha0Y, beta0Y, epsilonY);
plot(y, yp, 'Color', 'r', 'LineWidth', 2);
hold off;

%% Enhance plot
area = axis;
text(area(2), area(3), '\fontsize{15}\it\color{blue}x\color{black}, \color{red}y \rm\fontsize{10}\color{black}[mm] ', ...
    'HorizontalAlignment', 'right', 'VerticalAlignment', 'bottom');
text(area(1), area(4)*0.97, '\fontsize{15}\it\color{blue} x''\color{black}, \color{red}y'' \rm\fontsize{10}\color{black}[mrad]', ...
    'HorizontalAlignment', 'left', 'VerticalAlignment', 'top');
set(handles.axPhaseSpace, 'box', 'on');
grid on;