function [phi_H, phi_V] = calc_FODO_TBL_func(I1, I2, E)
% calc's phi's from currents and energy
% I1, I2 [A]
% E [MeV]
% EA, 27/4/2010 - Updated 1/7/2010 by RLL

% example current [here taken as input from user]
IQFR0200 = I1;
IQDR0240 = I2;
 
% from madx 
CLIGHT	= 299792458;
LQLX	= 0.186;
ECQDX	= 0.873;	% excitation constant dB/dx/I = 0.873 T/Am
FQDX	= CLIGHT * 1E-6 * ECQDX;       % for TBL
P08     = sqrt(E^2 - 0.510998902^2);	% momentum
KQFR0200    = -FQDX * IQFR0200 / P08;
KQFR0240    = -FQDX * IQDR0240 / P08;

l = LQLX;           % [m]
L_FODO = 2.82002;	% [m]

k1 =  abs(KQFR0200);
k2 =  abs(KQFR0240);

OO = zeros(2,2);

% Thick lens
% k = abs(k1);
% phi = l*sqrt(k);
% M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
%        -sqrt(k)*sin(phi)    cos(phi)];
% M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
%        sqrt(k)*sinh(phi)    cosh(phi)];
% M4_F = [M_F OO; OO M_D];

k = abs(k2);
phi = l*sqrt(k);
M_F = [cos(phi)             (1/sqrt(k))*sin(phi)
       -sqrt(k)*sin(phi)    cos(phi)];
M_D = [cosh(phi)             (1/sqrt(k))*sinh(phi)
       sqrt(k)*sinh(phi)    cosh(phi)];
M4_D = [M_D OO; OO M_F];
% M4_F = [M_F OO; OO M_D];    % Not switched 01/09/10

l05 = l/2;
k = abs(k1);
phi05 = l05*sqrt(k);
M_F05 = [cos(phi05)             (1/sqrt(k))*sin(phi05)
       -sqrt(k)*sin(phi05)    cos(phi05)];
M_D05 = [cosh(phi05)             (1/sqrt(k))*sinh(phi05)
       sqrt(k)*sinh(phi05)    cosh(phi05)];
M4_F05 = [M_F05 OO; OO M_D05];
% M4_D05 = [M_D05 OO; OO M_F05];  % Not switched 01/09/10

% k = abs(k2);
% phi05 = l05*sqrt(k);
% M_F05 = [cos(phi05)             (1/sqrt(k))*sin(phi05)
%        -sqrt(k)*sin(phi05)    cos(phi05)];
% M_D05 = [cosh(phi05)             (1/sqrt(k))*sinh(phi05)
%        sqrt(k)*sinh(phi05)    cosh(phi05)];
% M4_D05 = [M_D05 OO; OO M_F05];

d = L_FODO/2 - l;
M_0 = [1 d; 0 1];
M4_0 = [M_0 OO; OO M_0];

M4 = M4_F05*M4_0*M4_D*M4_0*M4_F05;
% M4 = M4_D05*M4_0*M4_F*M4_0*M4_D05;  % Not Switched 01/09/10

% HOR
M = M4(1:2,1:2);

cos1 = 0.5*trace(M);
phi_thick = acos(cos1);
% phi_deg_thick = (180/pi)*phi_thick;
% beta_thick = M(1,2) / sin(phi_thick);
phi_H = phi_thick;

% VER
M = M4(3:4,3:4);

cos1 = 0.5*trace(M);
phi_thick = acos(cos1);
% phi_deg_thick = (180/pi)*phi_thick;
% beta_thick = M(1,2) / sin(phi_thick);
phi_V = phi_thick;

return;
