function btnPowerPred_callback(hObject, eventdata, handles)
%% Read parameters from file
fid = fopen('parameters_pets.txt', 'r');
val = textscan(fid, '%q %q %f', 'HeaderLines', 4);
val = val{:,3};
fclose(fid);

RQ = val(2);
f_rf = val(3);
beta_g = val(4);
L_PETS = val(5);
eta = val(6);

fid = fopen('BPMOutput/mean.txt', 'r');
meanvals = textscan(fid, '%s %f', 'HeaderLines', 1);
meanvals = meanvals{:,2}';
fclose(fid);

if length(meanvals) >= 11
    I = meanvals(14);   % Using BPM 0310 now!
else
    I = 0;
end

%% Read parameters from user input
try
    F = str2double(get(handles.edtPowerPredFormFactor, 'String'));
    delta_f = str2double(get(handles.edtPowerPredDeltaF, 'String')) * 1e6;
catch
    disp('Error when reading user input. Stopping calculation.');
    return;
end

% I = 28;

%% Calculate detuning reduction factor
c = 299792458;
t_fill = L_PETS / beta_g / c * (1 - beta_g);

if delta_f > 1e3
    detuning_red = (1 - cos(2*pi*t_fill*delta_f)) / (1 - cos(2*pi*delta_f / f_rf)) / (t_fill * f_rf)^2;
else
    detuning_red = 1;
end

%% Do the calculation (cf. Erik Adli's PhD thesis eqs 4.13 and 4.16)
P = 0.25*RQ*2*pi*f_rf/beta_g/c * L_PETS^2 * I^2 * F^2 * eta^2 * detuning_red;
U = sqrt(0.25*L_PETS^2 * RQ*2*pi*f_rf/beta_g/c * P);

% Scale to MW and MV, respectively
P = P/1e6;
U = U/1e6;

%% Update the UI labels
set(handles.txtPowerPredVal, 'String', num2str(P, '%3.2f'));
set(handles.txtEnergyLossPredVal, 'String', num2str(U, '%2.3f'));