function timerFunction(hObject, eventdata, handles)
% Updates the current user screen periodically

% Global variables (defined elsewhere, written here because of scope)
global G_userscreen_no;
global G_pos_bpm;
global G_PetsApertureRadius;
global G_isonline;
isreaderror = 0;
if (G_userscreen_no ~= 1) && (G_userscreen_no ~= 2) && (G_userscreen_no ~= 3)
    disp(['Warning: Variable ''userscreen_no'' was ''' num2str(G_userscreen_no) ...
        '''. Setting to ''1'' instead.']);
    G_userscreen_no = 1;
end

% disp('Start of timer function...');

pause(0.2);

switch G_userscreen_no
    % Update selected screen only
    case 1
        % Update the BPM positions and currents
        ReadBpmsAndDisplay(handles);
        
        % Update magnet currents if the user is not editing them
        if (get(handles.btnEditSteering, 'Value') == 0)
            UpdateCorrectorsAndMovers(handles.edtBendCurrent);
        end
    case 2
        % Update the power pulses, position etc.
        ReadPowerPulsesAndDisplay(handles);
        
%         disp('Pulse reading done. Starting to read 3 mean values.'); % TODO: Remove
        
        % Find position of the 3 BPMs used with PETS offsets
        try
            posX = str2double(get(handles.edtPETSPosX, 'String'));
            posY = str2double(get(handles.edtPETSPosY, 'String'));
        catch
            s = lasterror;
            disp(['Error when reading positions from text boxes: ' s.message]);
        end
        
        % Find the bpm values
        if G_isonline
            try
                fid = fopen('BPMOutput/mean.txt');
                input = textscan(fid, '%s %f', 'HeaderLines', 1);
                input = input{:,2}';
                if size(input,2) == 57
                    bpmValX = input([1 7 10]);
                    bpmValY = input([3 9 12]);
                else
                    isreaderror = 1;
                    disp('Error when reading BPM mean values');
                end
                fclose(fid);
            catch
                s = lasterror;
                disp(['Error when reading mean BPM values: ' s.message])
            end
        end
        if ~G_isonline || isreaderror
            bpmValX = [0 posX posX] + 0.05*randn(1,3);
            bpmValY = [0 posY posY] + 0.05*randn(1,3);
        end
        
        % Update the BPM position plot
%         radius = handles.PETSApertureRadius;
        try
            yscale = ceil(G_PetsApertureRadius/4)*4;
            ytick = (-yscale/4:yscale/4) * 4;
            bpmpos = G_pos_bpm(1, 3:5);
            xrange = [bpmpos(1)-0.1*(bpmpos(3)-bpmpos(1)), bpmpos(3)+0.1*(bpmpos(3)-bpmpos(1))];
            cla(handles.axPETSPosReal);
            hold(handles.axPETSPosReal, 'on');
            %plot(handles.axPETSPosReal, xrange, [0 0], ':', 'Color', [0.5 0.5 0.5]);
            bpmValXPlot = bpmValX;  % Show zeros in case of NaN readings
            bpmValYPlot = bpmValY;
            bpmValXPlot(isnan(bpmValXPlot)) = 0;
            bpmValYPlot(isnan(bpmValYPlot)) = 0;
            plot(handles.axPETSPosReal, bpmpos, bpmValXPlot, 'b-s', 'MarkerFaceColor', [0.8 1 0], 'MarkerSize', 5);
            plot(handles.axPETSPosReal, bpmpos, bpmValYPlot, 'r-o', 'MarkerFaceColor', [0.8 1 0], 'MarkerSize', 5);
            text(bpmpos(1), yscale*0.95, ...
                '\fontsize{13}\it\color{blue}x\color{black}, \color{red}y', ...
                'VerticalAlignment', 'top', 'Parent', handles.axPETSPosReal);
            set(handles.axPETSPosReal, 'YGrid', 'on', 'XGrid', 'on');
        catch
            s = lasterror;
            disp(['Error when plotting mean BPM values: ' s.message]);
        end
        hold(handles.axPETSPosReal, 'off');
        set(handles.axPETSPosReal, 'XLim', xrange, 'YLim', [-yscale yscale], ...
            'YTick', ytick);
        
        % Update the BPM position texts as well
        set(handles.txtPETSPosBPM1x, 'String', num2str(bpmValX(1),'%5.3f'));
        set(handles.txtPETSPosBPM1y, 'String', num2str(bpmValY(1),'%5.3f'));
        set(handles.txtPETSPosBPM2x, 'String', num2str(bpmValX(2),'%5.3f'));
        set(handles.txtPETSPosBPM2y, 'String', num2str(bpmValY(2),'%5.3f'));
        set(handles.txtPETSPosBPM3x, 'String', num2str(bpmValX(3),'%5.3f'));
        set(handles.txtPETSPosBPM3y, 'String', num2str(bpmValY(3),'%5.3f'));
    case 3
end